@@ -406,23 +406,12 @@ impl<C> Matrix<C> {
     /// assert_eq!(m.move_in_direction(&(1, 1), (2, 1)), Some((3, 2)));
     /// ```
     #[must_use]
-    #[allow(clippy::cast_possible_wrap, clippy::cast_sign_loss)]
     pub fn move_in_direction(
         &self,
         index: &(usize, usize),
         direction: (isize, isize),
     ) -> Option<(usize, usize)> {
-        let &(row, col) = index;
-        if row >= self.rows || col >= self.columns || direction == (0, 0) {
-            return None;
-        }
-        let (new_row, new_col) = (row as isize + direction.0, col as isize + direction.1);
-        if new_row < 0 || new_col < 0 {
-            return None;
-        }
-        let (new_row, new_col) = (new_row as usize, new_col as usize);
-        (new_row < self.rows && new_col < self.columns)
-            .then(|| (new_row as usize, new_col as usize))
+        move_in_direction(index, direction, self.rows, self.columns)
     }
 
     /// Return an iterator of cells in a given direction starting from
@@ -450,25 +439,14 @@ impl<C> Matrix<C> {
     /// assert_eq!(m.in_direction(&(3, 2), directions::NW).collect::<Vec<_>>(),
     ///            vec![(2, 1), (1, 0)]);
     /// ```
-    ///
-    /// Collect a list of cells while avoiding keeping a reference onto the
-    /// matrix itself:
-    ///
-    /// ```
-    /// use pathfinding::prelude::{Matrix, directions};
-    /// let mut m = Matrix::new_square(8, '.');
-    /// let cells = m.in_direction(&(3, 2), directions::NW).collect::<Vec<_>>();
-    /// for cell in cells {
-    ///   m[&cell] = '+';
-    /// }
-    /// ```
     pub fn in_direction(
         &self,
         index: &(usize, usize),
         direction: (isize, isize),
-    ) -> impl Iterator<Item = (usize, usize)> + '_ {
+    ) -> impl Iterator<Item = (usize, usize)> {
+        let (rows, columns) = (self.rows, self.columns);
         itertools::unfold(*index, move |current| {
-            self.move_in_direction(current, direction).map(|next| {
+            move_in_direction(current, direction, rows, columns).map(|next| {
                 *current = next;
                 next
             })
@@ -649,3 +627,23 @@ pub mod directions {
     /// Eight main directions with diagonals
     pub const DIRECTIONS_8: [(isize, isize); 8] = [NE, E, SE, S, SW, W, NW, N];
 }
+
+#[must_use]
+#[allow(clippy::cast_possible_wrap, clippy::cast_sign_loss)]
+fn move_in_direction(
+    index: &(usize, usize),
+    direction: (isize, isize),
+    rows: usize,
+    columns: usize,
+) -> Option<(usize, usize)> {
+    let &(row, col) = index;
+    if row >= rows || col >= columns || direction == (0, 0) {
+        return None;
+    }
+    let (new_row, new_col) = (row as isize + direction.0, col as isize + direction.1);
+    if new_row < 0 || new_col < 0 {
+        return None;
+    }
+    let (new_row, new_col) = (new_row as usize, new_col as usize);
+    (new_row < rows && new_col < columns).then(|| (new_row as usize, new_col as usize))
+}
